#
# spec file for package yacreader
#
# Copyright (c) 2025 SUSE LLC
# Copyright (c) 2019 Xu Zhao (i@xuzhao.net).
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define p7zip_version 16.02
%define srcext        tar.zst
Name:           yacreader
Version:        9.15.0
Release:        1.2
Summary:        The best way for reading your comics
License:        GPL-3.0-or-later
Group:          Productivity/Graphics/Viewers
URL:            https://www.yacreader.com
Source0:        yacreader-%{version}.%{srcext}
Source1:        unarr.%{srcext}
# Source URL: https://sourceforge.net/projects/p7zip/files/p7zip/16.02/p7zip_16.02_src_all.tar.bz2/download
Source2:        p7zip_%{p7zip_version}_src_all.tar.bz2
Patch1:         0001-fix-unarr.patch
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  glu-devel
BuildRequires:  hicolor-icon-theme
BuildRequires:  libpoppler-qt6-devel
BuildRequires:  mozilla-nss
BuildRequires:  qt6-base-devel
BuildRequires:  qt6-declarative-devel
BuildRequires:  qt6-linguist-devel
BuildRequires:  qt6-multimedia-devel
BuildRequires:  qt6-qml-devel
BuildRequires:  qt6-qt5compat-devel
BuildRequires:  qt6-quickcontrols2-devel
BuildRequires:  qt6-sql-devel
BuildRequires:  qt6-svg-devel
BuildRequires:  unzip
BuildRequires:  update-desktop-files
BuildRequires:  zstd
Requires:       hicolor-icon-theme

%description
A cross platform comic reader and library manager.

%prep
%setup -q -a 1 -a 2
mv unarr compressed_archive/unarr/unarr-master
%patch -P 1 -p1
mv p7zip_%{p7zip_version} compressed_archive/libp7zip

%build
qmake6
make %{?_smp_mflags}

%install
INSTALL_ROOT=%{buildroot} %make_install
rm %{buildroot}/%{_datadir}/applications/*.desktop
%suse_update_desktop_file -i YACReader
%suse_update_desktop_file -i YACReaderLibrary
%fdupes %{buildroot}

%files
%{_bindir}/*
%{_mandir}/man1/*
%{_datadir}/yacreader
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/scalable/apps/*
%{_datadir}/doc/yacreader
/usr/lib/systemd/user/yacreaderlibraryserver.service

%changelog
* Fri Jan  3 2025 Xu Zhao <i@xuzhao.net>
- Update to 9.15.0
  * Save magnifying glass size and zoom level.
  * Bump PDF render size.
  * Fix trackpad scrolling.
- Use obs_scm to manage source code
* Wed Feb 21 2024 Xu Zhao <i@xuzhao.net>
- Update to 9.14.2.2402143
  * Fix columns in the search results.
  * Fix type not being propagated to new folders from their parents.
  * Improve and fix comic file size format.
- Version 9.14.1
  * Add setting to disable scroll animations and scroll smoothing.
  * Fix missing translation when opening YACReader from
    YACReaderLibrary.
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Fri Jul 21 2023 Xu Zhao <i@xuzhao.net>
- Update to 9.13.1
  * Fix crash when dropping comics in sublists
- Version 9.13.0
  * Avoid showing stale information in the server config
    dialog by updating the connection information
    when the dialog is opened.
  * Add new metadata support, it improves compatibility
    with ComicInfo.xml
* Tue Feb 28 2023 Xu Zhao <i@xuzhao.net>
- Update to 9.11.0
- Revert to unarr backend because of p7zip build failure.
* Sun Jul 10 2022 Xu Zhao <i@xuzhao.net>
- Switch to p7zip backend to support RAR5 format.
* Thu Mar 24 2022 Xu Zhao <i@xuzhao.net>
- Update to 9.8.2
* Fri Jun 11 2021 Xu Zhao <i@xuzhao.net>
- Update to 9.8.1
  * New search engine
  * Add support for full manga mode
  * Improve keyboard navigation in Comic Vine dialog
  * Fix "reading lists" reading order on YACReader
* Fri Jan  1 2021 Xu Zhao <i@xuzhao.net>
- Update to 9.7.1
  * Fix enlargement/stretching default value
- Update to 9.7.0
  * Image enlargement/stretching can now be disabled for fit to
    width and height
  * New option to show covers as single pages in double page mode
    (enabled by default)
* Sun Oct 13 2019 Xu Zhao <i@xuzhao.net>
- Initial commit v9.6.2
- v9.6.1
  * Fixes PDF support in macros
